@@ -87,10 +87,10 @@ List build_four(Geometry x){
       List coordinates;
       size_t groups = x.lengths(++cursor);
       for (size_t i = 0; i < groups; i++){
-        size_t groupsize = x.lengths(++cursor);
+        R_xlen_t groupsize = x.lengths(++cursor);
         Rcpp::List group;
         std::vector<double> vec(dim);
-        for (size_t j = 0; j < groupsize; j++){
+        for (R_xlen_t j = 0; j < groupsize; j++){
           for (size_t k = 0; k < dim; k++){
             vec[k] += x.coords((offset + j) * dim + k) / multiplier;
           }
